.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _canary-vvtest:

canary_vvtest
=============

The `canary_vvtest <https://github.com/sandialabs/canary/tree/main/src/canary_vvtest>`_ plugin extends `canary <https://github.com/sandialabs/canary>`_ to read and execute `vvtest <https://github.com/sandialabs/vvtest>`_ formatted test files.

Installation
------------

At this time, ``canary_vvtest`` is installed with ``canary``::

   pip install canary-wm
